@@ -3,7 +3,7 @@
 
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -35,6 +35,7 @@
 #include "oxygenhoverengine.h"
 #include "oxygenmainwindowengine.h"
 #include "oxygenmenubarstateengine.h"
+#include "oxygenmenuitemengine.h"
 #include "oxygenmenustateengine.h"
 #include "oxygenpanedengine.h"
 #include "oxygenscrollbarengine.h"
@@ -127,6 +128,10 @@ namespace Oxygen
         MainWindowEngine& mainWindowEngine( void ) const
         { return *_mainWindowEngine; }
 
+        //! menu item engine
+        MenuItemEngine& menuItemEngine( void ) const
+        { return *_menuItemEngine; }
+
         //! hover engine
         HoverEngine& hoverEngine( void ) const
         { return *_hoverEngine; }
@@ -256,6 +261,9 @@ namespace Oxygen
         //! main window engine
         MainWindowEngine* _mainWindowEngine;
 
+        //! menu item engine
+        MenuItemEngine* _menuItemEngine;
+
         //! paned engine
         PanedEngine* _panedEngine;
 
