@@ -2,7 +2,7 @@
 #define oxygeninnershadowdata_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -37,8 +37,7 @@ namespace Oxygen
 
         //! constructor
         InnerShadowData( void ):
-            _target(0),
-            _compositeEnabled(false)
+            _target(0)
         {}
 
         //! destructor
@@ -70,7 +69,8 @@ namespace Oxygen
 
         //! target widget
         GtkWidget* _target;
-        bool _compositeEnabled;
+
+        //! expose
         Signal _exposeId;
 
         //! child data
