@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -27,12 +27,18 @@ namespace Oxygen
 {
 
     //_____________________________________________
-    FontInfo::operator std::string ( void ) const
+    std::string FontInfo::toString( bool addQuotes ) const
     {
         std::ostringstream out;
-        out << "\"" << family() << " " << weightString() << " ";
+
+        if( addQuotes ) out << "\"";
+
+        out << family() << " " << weightString() << " ";
         if( _italic ) out << italicString() << " ";
-        out << size() << "\"";
+        out << size() ;
+
+        if( addQuotes ) out << "\"";
+
         return out.str();
     }
 
